#include "ByteConverterDialog.h"
#include <iostream>

ByteConverterDialog::ByteConverterDialog(QWidget *parent) :
QDialog(parent) {
   // main-Layout: top: LineEdits, bottom: Exit-Button
   QVBoxLayout* mainLayout = new QVBoxLayout(this);
   // Layout for LineEdits and corr. labels
   QGridLayout* editLayout = new QGridLayout();
   // used to push exit-button to the right
   QHBoxLayout* buttonLayout = new QHBoxLayout();   

   mainLayout->addLayout(editLayout);
   mainLayout->addStretch();
   mainLayout->addLayout(buttonLayout); 

   // create labels and lineEdits
   QLabel* decLabel = new QLabel(tr("Dezimal"));
   QLabel* hexLabel = new QLabel(tr("Hexadezimal"));
   QLabel* binLabel = new QLabel(tr("Binary"));
   decEdit = new QLineEdit(this);
   hexEdit = new QLineEdit(this);
   binEdit = new QLineEdit(this);
   // add labels and lineEdits to grid-Layout 
   editLayout->addWidget(decLabel, 0, 0);
   editLayout->addWidget(decEdit, 0, 1);
   editLayout->addWidget(hexLabel, 1, 0);
   editLayout->addWidget(hexEdit, 1, 1);
   editLayout->addWidget(binLabel, 2, 0);
   editLayout->addWidget(binEdit, 2, 1);

   // create exitButton and add it
   QPushButton* exitButton = new QPushButton(tr("Exit"));
   buttonLayout->addStretch();
   buttonLayout->addWidget(exitButton);

   setWindowTitle(tr("Zahlen-Converter"));
   exitButton->setDefault(true);
   connect(exitButton, SIGNAL(clicked()), this, SLOT(accept()));

   // create validators to make sure that user does not enter wrong stuff
   QIntValidator* decValidator = new QIntValidator(0, 255, decEdit);
   decEdit->setValidator(decValidator);

   QRegExpValidator* hexValidator = new QRegExpValidator(QRegExp("[0-9A-Fa-f]{1,2}"), hexEdit);
   hexEdit->setValidator(hexValidator);
   
   QRegExpValidator* binValidator = new QRegExpValidator(QRegExp("[01]{1,8}"), binEdit);
   binEdit->setValidator(binValidator);
   
   // connect QLineEdits with changed-methods
   connect(decEdit, SIGNAL(textEdited(const QString&)), this, SLOT(decChanged(const QString&)));
   connect(hexEdit, SIGNAL(textEdited(const QString&)), this, SLOT(hexChanged(const QString&)));
   connect(binEdit, SIGNAL(textEdited(const QString&)), this, SLOT(binChanged(const QString&)));
   
}



void ByteConverterDialog::decChanged(const QString& newVal) {
   bool ok;
   int num = newVal.toInt(&ok);
   if(ok) {
      hexEdit->setText(QString::number(num, 16));
      binEdit->setText(QString::number(num, 2));
   } else {
      hexEdit->setText("");
      binEdit->setText("");
   }
}

void ByteConverterDialog::hexChanged(const QString& newVal) {
   bool ok;
   int num = newVal.toInt(&ok, 16);
   if(ok) {
      decEdit->setText(QString::number(num));
      binEdit->setText(QString::number(num, 2));
   } else {
      decEdit->setText("");
      binEdit->setText("");
   }
}

void ByteConverterDialog::binChanged(const QString& newVal) {
   bool ok;
   int num = newVal.toInt(&ok, 2);
   if(ok) {
      decEdit->setText(QString::number(num));
      hexEdit->setText(QString::number(num, 16));
   } else {
      decEdit->setText("");
      hexEdit->setText("");
   }
}

